@@ -28,6 +28,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtr-utils.h"
 #include "gtr-dirs.h"
 
@@ -679,68 +683,6 @@ finally_2:
   return ret;
 }
 
-/**
- * gtr_utils_activate_url:
- * @dialog: a #GtkAboutDialog
- * @url: the url to show
- * @data: useless data variable
- * 
- * Shows the corresponding @url in the default browser.
- */
-void
-gtr_utils_activate_url (GtkAboutDialog * dialog,
-                        const gchar * url, gpointer data)
-{
-  //FIXME: gtk_url_show deprecates this func.
-  gchar *open[3];
-
-  if (g_find_program_in_path ("xdg-open"))
-    {
-      open[0] = "xdg-open";
-    }
-  else
-    return;
-
-  open[1] = (gchar *) url;
-  open[2] = NULL;
-
-  gdk_spawn_on_screen (gdk_screen_get_default (),
-                       NULL,
-                       open,
-                       NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
-}
-
-/**
- * gtr_utils_activate_email:
- * @dialog: a #GtkAboutDialog
- * @email: the email to show
- * @data: useless data variable
- * 
- * Shows the corresponding @email in the default mailer.
- */
-void
-gtr_utils_activate_email (GtkAboutDialog * dialog,
-                          const gchar * email, gpointer data)
-{
-  //FIXME: gtk_url_show deprecates this func.
-  gchar *open[3];
-
-  if (g_find_program_in_path ("xdg-email"))
-    {
-      open[0] = "xdg-email";
-    }
-  else
-    return;
-
-  open[1] = (gchar *) email;
-  open[2] = NULL;
-
-  gdk_spawn_on_screen (gdk_screen_get_default (),
-                       NULL,
-                       open,
-                       NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
-}
-
 /**
  * gtr_utils_help_display:
  * @parent: a #GtkWindow
@@ -755,12 +697,11 @@ gtr_utils_help_display (GtkWindow * parent,
 {
 
   GError *error = NULL;
-  GdkScreen *screen;
   gchar *command;
   const gchar *lang;
   const gchar *const *langs;
+  const gchar *path;
   gchar *uri = NULL;
-  gchar *path;
   gint i;
 
 
@@ -790,10 +731,9 @@ gtr_utils_help_display (GtkWindow * parent,
       if (strchr (lang, '.'))
         continue;
 
-      path = gtr_dirs_get_gtr_data_dir ();
-      uri = g_build_filename (path, "gnome", "help", doc_id,
+      path = gtr_dirs_get_gtr_help_dir ();
+      uri = g_build_filename (path, doc_id,
                               lang, file_name, NULL);
-      g_free (path);
 
       if (g_file_test (uri, G_FILE_TEST_EXISTS))
         {
@@ -823,8 +763,7 @@ gtr_utils_help_display (GtkWindow * parent,
   command = g_strconcat ("gnome-help ghelp://", uri, NULL);
   g_free (uri);
 
-  screen = gtk_widget_get_screen (GTK_WIDGET (parent));
-  gdk_spawn_command_line_on_screen (screen, command, &error);
+  g_spawn_command_line_async (command, &error);
 
 
   if (error != NULL)
@@ -886,8 +825,8 @@ gtr_utils_get_current_year (void)
  * @po_name: the name of the specific po file to search or NULL.
  *
  * Scans the directory and subdirectories of @dir looking for filenames remained
- * with .po or files that matches @po_name. The contents of @list must be freed with
- * g_slist_foreach (list, (GFunc)g_object_unref, NULL).
+ * with .po or files that matches @po_name. @list must be freed with
+ * g_slist_free_full (list, g_object_unref).
  */
 void
 gtr_utils_scan_dir (GFile * dir, GSList ** list, const gchar * po_name)
