@@ -253,7 +253,6 @@ gtr_gda_store_impl (GtrGda *self,
 {
   gint orig_id;
   gboolean found_translation = FALSE;
-  gchar *norm_translation = NULL;
   gchar **words = NULL;
   GError *inner_error;
 
@@ -270,9 +269,6 @@ gtr_gda_store_impl (GtrGda *self,
       return FALSE;
     }
 
-  norm_translation = g_utf8_normalize (translation, -1,
-                                       G_NORMALIZE_DEFAULT);
-
   if (orig_id == 0)
     {
       gsize sz, i;
@@ -314,7 +310,7 @@ gtr_gda_store_impl (GtrGda *self,
                                                               orig_id,
                                                               "value",
                                                               G_TYPE_STRING,
-                                                              norm_translation),
+                                                              translation),
                                           &inner_error);
       if (inner_error)
         goto error;
@@ -329,17 +325,15 @@ gtr_gda_store_impl (GtrGda *self,
                                       "orig_id", G_TYPE_INT,
                                       orig_id,
                                       "value", G_TYPE_STRING,
-                                      norm_translation),
+                                      translation),
                   &inner_error);
       if (inner_error)
         goto error;
     }
 
-  g_free (norm_translation);
   return TRUE;
 
  error:
-  g_free (norm_translation);
   g_strfreev (words);
   g_propagate_error (error, inner_error);
   return FALSE;
@@ -440,16 +434,12 @@ gtr_gda_remove (GtrTranslationMemory *tm,
                 const gchar *translation)
 {
   GtrGda *self = GTR_GDA (tm);
-  gchar *norm_translation;
   GdaSet *params;
   GError *error;
 
-  norm_translation = g_utf8_normalize (translation, -1,
-                                       G_NORMALIZE_DEFAULT);
-
   params = gda_set_new_inline (2,
                                "original", G_TYPE_STRING, original,
-                               "value", G_TYPE_STRING, norm_translation);
+                               "value", G_TYPE_STRING, translation);
 
   error = NULL;
   gda_connection_statement_execute_non_select (self->priv->db,
@@ -464,12 +454,13 @@ gtr_gda_remove (GtrTranslationMemory *tm,
     }
 
   g_object_unref (params);
-  g_free (norm_translation);
 }
 
 static void
-free_match (GtrTranslationMemoryMatch *match, gpointer dummy)
+free_match (gpointer data)
 {
+  GtrTranslationMemoryMatch *match = (GtrTranslationMemoryMatch *) data;
+
   g_free (match->match);
   g_slice_free (GtrTranslationMemoryMatch, match);
 }
@@ -671,8 +662,7 @@ gtr_gda_lookup (GtrTranslationMemory * tm, const gchar * phrase)
 
   if (inner_error)
     {
-      g_list_foreach (matches, (GFunc) free_match, NULL);
-      g_list_free (matches);
+      g_list_free_full (matches, free_match);
 
       g_warning ("%s\n", inner_error->message);
 
@@ -755,7 +745,7 @@ gtr_gda_init (GtrGda * self)
   gda_init ();
 
   {
-    gchar *config_dir;
+    const gchar *config_dir;
     gchar *encoded_config_dir;
 
     config_dir = gtr_dirs_get_user_config_dir ();
@@ -766,7 +756,6 @@ gtr_gda_init (GtrGda * self)
                                          encoded_config_dir);
 
     g_free (encoded_config_dir);
-    g_free (config_dir);
   }
 
   self->priv->db = gda_connection_open_from_string ("Sqlite",
